@@ -1069,7 +1069,7 @@ void ComicApplet::buttonBar()
 void ComicApplet::fullView()
 {
     if ( !mFullViewWidget ) {
-        mFullViewWidget = new FullViewWidget();
+        mFullViewWidget = new FullViewWidget;
     }
 
     if ( !mFullViewWidget->isVisible() ) {
