@@ -22,12 +22,10 @@
 #include "previewwidget.h"
 
 // Qt
-#include <QPainter>
 #include <QGraphicsSceneDragDropEvent>
-#include <QLabel>
-#include <QPalette>
 #include <QDesktopWidget>
 #include <QApplication>
+#include <QLabel>
 
 // KDE
 #include <KIcon>
@@ -39,11 +37,10 @@
 #include <KAction>
 #include <KUrl>
 #include <KService>
-#include <KGlobalSettings>
-#include <KFileItem>
 #include <KIO/DeleteJob>
 #include <KRun>
 #include <KMessageBox>
+#include <KDebug>
 
 // Plasma
 #include <plasma/theme.h>
@@ -63,15 +60,15 @@ Previewer::Previewer(QObject *parent, const QVariantList &args)
     QDBusConnection dbus = QDBusConnection::sessionBus();
     dbus.registerObject("/Previewer", this);
 
-    setAspectRatioMode(Plasma::IgnoreAspectRatio);
-
     setAcceptHoverEvents(true);
     setAcceptDrops(true);
+    setBackgroundHints(NoBackground);
 
     resize(PreviewWidget::suggestedWidth(), 150);
     if (args.count()) {
         kDebug() << "Opening file from arg passed into applet ..." << args.value(0).toString();
         m_currentFile = args.value(0).toString();
+        setAssociatedApplicationUrls(KUrl(m_currentFile));
     }
 }
 
@@ -86,6 +83,11 @@ Previewer::~Previewer()
     }
 }
 
+void Previewer::setStartSize()
+{
+    resize(PreviewWidget::suggestedWidth(), 150);
+}
+
 QGraphicsWidget* Previewer::graphicsWidget()
 {
     if (!m_previewWidget) {
@@ -93,6 +95,7 @@ QGraphicsWidget* Previewer::graphicsWidget()
         m_previewWidget->setMinimumSize(200, m_previewWidget->iconSize().height() + m_previewWidget->s_topBorder +
                                         m_previewWidget->bottomBorderHeight());
         m_previewWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+        m_previewWidget->setPreferredSize(m_previewWidget->minimumSize());
         connect(m_previewWidget, SIGNAL(urlsDropped(KUrl::List)), this, SLOT(openUrls(KUrl::List)));
         connect(m_previewWidget, SIGNAL(fileOpenRequested(KUrl)), this, SLOT(openFile(KUrl)));
     }
@@ -103,7 +106,7 @@ QGraphicsWidget* Previewer::graphicsWidget()
 void Previewer::init()
 {
     setPopupIcon("previewer");
-    setupActions();
+    graphicsWidget();
     if (!m_currentFile.isEmpty()) {
         openFile(m_currentFile);
     }
@@ -112,31 +115,7 @@ void Previewer::init()
 void Previewer::constraintsEvent(Plasma::Constraints constraints)
 {
     Q_UNUSED(constraints)
-    setBackgroundHints(NoBackground);
-}
-
-void Previewer::setupActions()
-{
-    KAction *open = new KAction(KIcon("document-preview"), i18n("&Open"), this);
-    connect(open, SIGNAL(triggered()), this, SLOT(openFile()));
-
-    m_actions << open;
-
-    KAction *onTop = new KAction(i18n("Preview Dialog Always on Top"), this);
-    onTop->setCheckable(true);
-    onTop->setChecked(true);
-    connect(onTop, SIGNAL(toggled(bool)), this, SLOT(stayOnTop(bool)));
-    m_actions << onTop;
-
-    QAction *sep = new QAction(this);
-    sep->setSeparator(true);
-    m_actions << sep;
-
-    m_recents = new KMenu();
-    m_recents->setIcon(KIcon("document-open-recent"));
-    QAction *r_action = m_recents->menuAction();
-    r_action->setText(i18n("Recently Opened"));
-    m_actions<<r_action;
+    setAspectRatioMode(Plasma::IgnoreAspectRatio);
 }
 
 void Previewer::setupPreviewDialog()
@@ -169,7 +148,7 @@ void Previewer::stayOnTop(bool top)
 
 void Previewer::openFile(KUrl u)
 {
-    kDebug()<<"opening file";
+    kDebug() << "opening file";
     if (!u.isValid()) {
         u = KFileDialog::getOpenUrl();
 
@@ -202,6 +181,7 @@ void Previewer::openFile(KUrl u)
     if (m_part->openUrl(u)) {
         kDebug() << "part successfully created";
         m_currentFile = u.pathOrUrl();
+        setAssociatedApplicationUrls(KUrl(m_currentFile));
         m_dialog->setTitle(u.fileName());
         m_dialog->resize(600,500);
         QDesktopWidget *dw = QApplication::desktop();
@@ -209,7 +189,7 @@ void Previewer::openFile(KUrl u)
         m_dialog->show();
         m_base->setFocus(Qt::TabFocusReason);
 
-        if (!m_previewHistory.contains(u)) {
+        if (!m_previewWidget->previews().contains(u)) {
             addPreview(u);
         }
         //   browser->setCurrentUrl(u);
@@ -259,8 +239,7 @@ void Previewer::closeFile(bool hide)
 void Previewer::removeCurrentFromHistory()
 {
     KUrl cur(currentFile());
-    int index = m_previewHistory.indexOf(cur);
-    kDebug() << index;
+    int index = m_previewWidget->previews().indexOf(cur);
 
     m_dialog->setWindowFlags(Qt::FramelessWindowHint);
     m_dialog->show();
@@ -275,9 +254,8 @@ void Previewer::removeCurrentFromHistory()
         delete m_part;
         m_part = 0;
         m_dialog->hide();
-        removeRecent(index);
         KIO::del(cur);
-        m_previewWidget->setItemsList(m_previewHistory);
+        m_previewWidget->removeItem(index);
         return;
     }
 
@@ -296,8 +274,8 @@ void Previewer::dropEvent(QGraphicsSceneDragDropEvent *event)
 
 void Previewer::addPreview(const QUrl& url, KMimeType::Ptr mimeType)
 {
-    kDebug()<<"addPreview() reached";
-    if (m_previewHistory.contains(url)) {
+    kDebug() << "addPreview() reached";
+    if (m_previewWidget->previews().contains(url)) {
         return;
     }
 
@@ -315,47 +293,12 @@ void Previewer::addPreview(const QUrl& url, KMimeType::Ptr mimeType)
         return;
     }
 
-    if (!m_previewWidget) {
-        // make sure it's initialized!
-        graphicsWidget();
-    }
-
-    if (m_previewHistory.isEmpty()) {
+    if (m_previewWidget->previews().isEmpty()) {
         // animating this is WICKED smooth =)
-        m_previewWidget->expand();
+        m_previewWidget->animateHeight(true);
     }
 
-    KAction *a = new KAction(KIcon(mimeType->iconName()), KUrl(url).fileName(), this);
-    a->setData(url);
-    connect(a, SIGNAL(triggered()), this, SLOT(reopenPreview()));
-
-    addRecent(a, url);
-    m_previewWidget->setItemsList(m_previewHistory);
-}
-
-void Previewer::reopenPreview()
-{
-    KAction *s = qobject_cast<KAction*>(sender());
-    if (s) {
-        openFile(s->data().toUrl());
-    }
-}
-
-QList<QAction*> Previewer::contextualActions()
-{
-    return m_actions;
-}
-
-void Previewer::removeRecent(int index)
-{
-    m_previewHistory.takeAt(index);
-    delete m_recents->actions().takeAt(index);
-}
-
-void Previewer::addRecent(QAction *action, const QUrl &url)
-{
-    m_previewHistory.append(url);
-    m_recents->addAction(action);
+    m_previewWidget->addItem(url);
 }
 
 QString Previewer::currentFile()
@@ -390,7 +333,7 @@ void Previewer::slotRunClicked()
     KMimeType::Ptr mimeType = KMimeType::findByUrl(url, 0, true);
     KService::Ptr service = KMimeTypeTrader::self()->preferredService(mimeType->name());
     if (service) {
-        kDebug()<<service->exec();
+        //kDebug()<<service->exec();
         KRun::run(service->exec(), url, m_dialog);
     }
 
