@@ -24,7 +24,7 @@
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
 #include <QCoreApplication>
-#include <QWebView>
+#include <KWebView>
 #include <QPushButton>
 
 #include <KDebug>
@@ -62,8 +62,7 @@ void RTM::Auth::showLoginWebpage()
 
 void RTM::Auth::showLoginWindowInternal(RTM::Request *rawReply)
 {
-  QString reply = rawReply->data();
-  //QString reply = rawReply->readAll(); //FIXME: I have no idea why this line isn't working?
+  QString reply = rawReply->data(); // Get the full data of the reply, readAll() doesn't guarentee that.
   frob = reply.remove(0, reply.indexOf("<frob>")+6);
   frob.truncate(frob.indexOf("</frob>"));
   kDebug() << "Frob: " << frob;
@@ -73,9 +72,9 @@ void RTM::Auth::showLoginWindowInternal(RTM::Request *rawReply)
   QWidget *authWidget = new QWidget();
   QVBoxLayout *layout = new QVBoxLayout(authWidget);
   QPushButton *button = new QPushButton(authWidget);
-  QWebView *authPage  = new QWebView(authWidget);
+  KWebView *authPage  = new KWebView(authWidget);
   
-  button->setText(i18n("Click here after you've logged in and authorized the applet"));
+  button->setText(i18n("Click here after you have logged in and authorized the applet"));
 
   authPage->setUrl(getAuthUrl());
   
@@ -99,9 +98,8 @@ void RTM::Auth::pageClosed() {
 }
 
 QString RTM::Auth::getAuthUrl() {
-  if (frob.isEmpty()) {
+  if (frob.isEmpty())
     kWarning() << "Warning, Frob is EMPTY";
-  }
   return requestUrl();
 }
 
