@@ -42,21 +42,70 @@
 #include <KSystemTimeZones>
 #include <KTimeZone>
 #include <KDebug>
+#include <Solid/Networking>
+#include <QTimer>
 
 class RTM::SessionPrivate {
   SessionPrivate(Session *parent)
     : q(parent),
-      auth(0)
+      auth(0),
+      online(true)
   {
-
+      QObject::connect(Solid::Networking::notifier(), SIGNAL(statusChanged(Solid::Networking::Status)), q, SLOT(networkStatusChanged(Solid::Networking::Status)));
+      if (Solid::Networking::status() == Solid::Networking::Unconnected) {
+        online = false;
+        kDebug() << "We are NOT Online :(";
+      }
   }
   ~SessionPrivate() {
     if (auth)
       auth->deleteLater();
   }
 
+  void networkStatusChanged(Solid::Networking::Status status) {
+    switch (status) {
+    case Solid::Networking::Connected: case Solid::Networking::Unknown:
+        if (online)
+          return;
+
+        online = true;
+        q->checkToken();
+        refreshSettings();
+        q->refreshListsFromServer();
+        q->refreshTasksFromServer();
+        break;
+      case Solid::Networking::Unconnected:
+      case Solid::Networking::Disconnecting:
+      case Solid::Networking::Connecting:
+        if (!online)
+          return;
+
+        online = false;
+        break;
+      }
+  }
+  
+  void offlineError() {
+    online = false;
+    kDebug() << "retesting offline status in 60 seconds";
+    QTimer::singleShot(60*1000, q, SLOT(retestOfflineStatus()));
+  }
+  
+  void retestOfflineStatus() {
+    online = true;
+    kDebug() << "retesting offline status";
+    q->checkToken();
+  }
+  
+  void connectOfflineSignal(RTM::Request *request) {
+    QObject::connect(request, SIGNAL(offlineError()), q, SLOT(offlineError()));
+  }
+  
   void populateSmartList(List * list)
   {
+    if (!online)
+      return;
+
     kDebug() << "Populating Smart List: " << list->name();
     // We do this next bit manually so it doesn't get auto-connected to taskUpdate()
     RTM::Request *smartListRequest = new RTM::Request("rtm.tasks.getList", q->apiKey(), q->sharedSecret());
@@ -102,11 +151,8 @@ class RTM::SessionPrivate {
     
     reply->deleteLater();
   }
-  void refreshSettings() {
-    RTM::Request settingsRequest("rtm.settings.getList", q->apiKey(), q->sharedSecret());
-    settingsRequest.addArgument("auth_token", q->token());
-    
-    QString reply = settingsRequest.sendSynchronousRequest();
+  void settingsReply(RTM::Request* request) {
+    QString reply = request->data(); // Get the full data of the reply, readAll() doesn't guarentee that.
     
     // We're basically assuming no error here.... FIXME
     QString timezone = reply.remove(0, reply.indexOf("<timezone>")+10);
@@ -120,6 +166,19 @@ class RTM::SessionPrivate {
     
     this->timezone = KSystemTimeZones::zone(timezone);
     kDebug() << "Timezone Set To: " << timezone << " i.e. " << this->timezone.name();
+    
+    request->deleteLater();
+    emit q->settingsUpdated();
+  }
+  void refreshSettings() {
+    if (!online)
+      return;
+
+    RTM::Request *settingsRequest = new RTM::Request("rtm.settings.getList", q->apiKey(), q->sharedSecret());
+    settingsRequest->addArgument("auth_token", q->token());
+    
+    QObject::connect(settingsRequest, SIGNAL(replyReceived(RTM::Request*)), q, SLOT(settingsReply(RTM::Request*)));
+    settingsRequest->sendRequest();
   }
   
 
@@ -133,6 +192,7 @@ class RTM::SessionPrivate {
   QString sharedSecret;
   QString token;
   QDateTime lastRefresh;
+  bool online;
   RTM::Permissions permissions;
   KTimeZone timezone;
 
